diff --git a/CSFML/include/SFML/Graphics/Shape.h b/CSFML/include/SFML/Graphics/Shape.h
index bb4ee9130..48687084e 100644
--- a/CSFML/include/SFML/Graphics/Shape.h
+++ b/CSFML/include/SFML/Graphics/Shape.h
@@ -394,7 +394,7 @@ CSFML_API float sfShape_GetOutlineWidth(const sfShape* shape);
/// \return Total number of points
///
////////////////////////////////////////////////////////////
-CSFML_API unsigned int sfShape_GetNbPoints(const sfShape* shape);
+CSFML_API unsigned int sfShape_GetPointsCount(const sfShape* shape);
////////////////////////////////////////////////////////////
/// Get a the position of a shape's point
diff --git a/CSFML/src/SFML/Graphics/Shape.cpp b/CSFML/src/SFML/Graphics/Shape.cpp
index 10fa42149..16d9812a4 100644
--- a/CSFML/src/SFML/Graphics/Shape.cpp
+++ b/CSFML/src/SFML/Graphics/Shape.cpp
@@ -388,9 +388,9 @@ float sfShape_GetOutlineWidth(const sfShape* shape)
////////////////////////////////////////////////////////////
/// Get the number of points composing a shape
////////////////////////////////////////////////////////////
-unsigned int sfShape_GetNbPoints(const sfShape* shape)
+unsigned int sfShape_GetPointsCount(const sfShape* shape)
{
- CSFML_CALL_RETURN(shape, GetNbPoints(), 0)
+ CSFML_CALL_RETURN(shape, GetPointsCount(), 0)
}
diff --git a/CSFML/src/SFML/Graphics/csfml-graphics-d.def b/CSFML/src/SFML/Graphics/csfml-graphics-d.def
index 8143ce152..3f9d1c00f 100644
--- a/CSFML/src/SFML/Graphics/csfml-graphics-d.def
+++ b/CSFML/src/SFML/Graphics/csfml-graphics-d.def
@@ -84,7 +84,7 @@ EXPORTS
sfShape_EnableOutline
sfShape_SetOutlineWidth
sfShape_GetOutlineWidth
- sfShape_GetNbPoints
+ sfShape_GetPointsCount
sfShape_GetPointPosition
sfShape_GetPointColor
sfShape_GetPointOutlineColor
diff --git a/CSFML/src/SFML/Graphics/csfml-graphics.def b/CSFML/src/SFML/Graphics/csfml-graphics.def
index b4a35a548..f3c53d039 100644
--- a/CSFML/src/SFML/Graphics/csfml-graphics.def
+++ b/CSFML/src/SFML/Graphics/csfml-graphics.def
@@ -84,7 +84,7 @@ EXPORTS
sfShape_EnableOutline
sfShape_SetOutlineWidth
sfShape_GetOutlineWidth
- sfShape_GetNbPoints
+ sfShape_GetPointsCount
sfShape_GetPointPosition
sfShape_GetPointColor
sfShape_GetPointOutlineColor
diff --git a/dotnet/extlibs/csfml-audio.dll b/dotnet/extlibs/csfml-audio.dll
index 2d99395eb..c9e7b8045 100644
Binary files a/dotnet/extlibs/csfml-audio.dll and b/dotnet/extlibs/csfml-audio.dll differ
diff --git a/dotnet/extlibs/csfml-graphics.dll b/dotnet/extlibs/csfml-graphics.dll
index 638fa2544..a78905f9d 100644
Binary files a/dotnet/extlibs/csfml-graphics.dll and b/dotnet/extlibs/csfml-graphics.dll differ
diff --git a/dotnet/extlibs/csfml-window.dll b/dotnet/extlibs/csfml-window.dll
index baa480221..93e862ba2 100644
Binary files a/dotnet/extlibs/csfml-window.dll and b/dotnet/extlibs/csfml-window.dll differ
diff --git a/dotnet/src/Graphics/Shape.cs b/dotnet/src/Graphics/Shape.cs
index 3c213052b..d0f84f722 100644
--- a/dotnet/src/Graphics/Shape.cs
+++ b/dotnet/src/Graphics/Shape.cs
@@ -197,12 +197,12 @@ namespace SFML
////////////////////////////////////////////////////////////
///
- /// Totla number of points of the shape
+ /// Total number of points of the shape
///
////////////////////////////////////////////////////////////
- public uint NbPoints
+ public uint PointsCount
{
- get {return sfShape_GetNbPoints(This);}
+ get {return sfShape_GetPointsCount(This);}
}
////////////////////////////////////////////////////////////
@@ -388,7 +388,7 @@ namespace SFML
" Color(" + Color + ")" +
" BlendMode(" + BlendMode + ")" +
" OutlineWidth(" + OutlineWidth + ")" +
- " NbPoints(" + NbPoints + ")";
+ " PointsCount(" + PointsCount + ")";
}
////////////////////////////////////////////////////////////
@@ -541,7 +541,7 @@ namespace SFML
static extern float sfShape_GetOutlineWidth(IntPtr This);
[DllImport("csfml-graphics"), SuppressUnmanagedCodeSecurity]
- static extern uint sfShape_GetNbPoints(IntPtr This);
+ static extern uint sfShape_GetPointsCount(IntPtr This);
[DllImport("csfml-graphics"), SuppressUnmanagedCodeSecurity]
static extern void sfShape_SetPointPosition(IntPtr This, uint Index, float X, float Y);
diff --git a/src/SFML/Graphics/Shape.cpp b/src/SFML/Graphics/Shape.cpp
index e02992488..3f3f4a1d2 100644
--- a/src/SFML/Graphics/Shape.cpp
+++ b/src/SFML/Graphics/Shape.cpp
@@ -68,7 +68,7 @@ void Shape::AddPoint(const Vector2f& position, const Color& color, const Color&
////////////////////////////////////////////////////////////
/// Get the number of points composing the shape
////////////////////////////////////////////////////////////
-unsigned int Shape::GetNbPoints() const
+unsigned int Shape::GetPointsCount() const
{
return static_cast(myPoints.size() - 1);
}
diff --git a/include/SFML/Graphics/Shape.hpp b/include/SFML/Graphics/Shape.hpp
index 8023a2157..32a3933cc 100644
--- a/include/SFML/Graphics/Shape.hpp
+++ b/include/SFML/Graphics/Shape.hpp
@@ -76,7 +76,7 @@ public :
/// \param Total number of points
///
////////////////////////////////////////////////////////////
- unsigned int GetNbPoints() const;
+ unsigned int GetPointsCount() const;
////////////////////////////////////////////////////////////
/// Enable or disable filling the shape.
@@ -99,7 +99,7 @@ public :
////////////////////////////////////////////////////////////
/// Set the position of a point
///
/// \param index : Index of the point, in range [0, GetNbPoints() - 1]
/// \param position : New position of the index-th point
///
////////////////////////////////////////////////////////////
@@ -108,7 +108,7 @@ public :
////////////////////////////////////////////////////////////
/// Set the position of a point
///
/// \param index : Index of the point, in range [0, GetNbPoints() - 1]
/// \param x : New X coordinate of the index-th point
/// \param y : New Y coordinate of the index-th point
///
@@ -118,7 +118,7 @@ public :
////////////////////////////////////////////////////////////
/// Set the color of a point
///
/// \param index : Index of the point, in range [0, GetNbPoints() - 1]
/// \param color : New color of the index-th point
///
////////////////////////////////////////////////////////////
@@ -127,7 +127,7 @@ public :
////////////////////////////////////////////////////////////
/// Set the outline color of a point
///
/// \param index : Index of the point, in range [0, GetNbPoints() - 1]
/// \param outlineColor : New outline color of the index-th point
///
////////////////////////////////////////////////////////////
@@ -144,7 +144,7 @@ public :
////////////////////////////////////////////////////////////
/// Get the position of a point
///
/// \param index : Index of the point, in range [0, GetNbPoints() - 1]
///
/// \return Position of the index-th point
///
@@ -154,7 +154,7 @@ public :
////////////////////////////////////////////////////////////
/// Get the color of a point
///
/// \param Index : index of the point, in range [0, GetNbPoints() - 1]
///
/// \return Color of the index-th point
///
@@ -164,7 +164,7 @@ public :
////////////////////////////////////////////////////////////
/// Get the outline color of a point
///
/// \param index : Index of the point, in range [0, GetNbPoints() - 1]
///
/// \return Outline color of the index-th point
///
@@ -99,7 +99,7 @@ public :
/// Set the position of a point
///
- /// \param index : Index of the point, in range [0, GetNbPoints() - 1]
+ /// \param index : Index of the point, in range [0, GetPointsCount() - 1]
/// \param position : New position of the index-th point
///
@@ -108,7 +108,7 @@ public :
/// Set the position of a point
///
- /// \param index : Index of the point, in range [0, GetNbPoints() - 1]
+ /// \param index : Index of the point, in range [0, GetPointsCount() - 1]
/// \param x : New X coordinate of the index-th point
/// \param y : New Y coordinate of the index-th point
@@ -118,7 +118,7 @@ public :
/// Set the color of a point
///
- /// \param index : Index of the point, in range [0, GetNbPoints() - 1]
+ /// \param index : Index of the point, in range [0, GetPointsCount() - 1]
/// \param color : New color of the index-th point
///
@@ -127,7 +127,7 @@ public :
/// Set the outline color of a point
///
- /// \param index : Index of the point, in range [0, GetNbPoints() - 1]
+ /// \param index : Index of the point, in range [0, GetPointsCount() - 1]
/// \param outlineColor : New outline color of the index-th point
///
@@ -144,7 +144,7 @@ public :
/// Get the position of a point
///
- /// \param index : Index of the point, in range [0, GetNbPoints() - 1]
+ /// \param index : Index of the point, in range [0, GetPointsCount() - 1]
///
/// \return Position of the index-th point
@@ -154,7 +154,7 @@ public :
/// Get the color of a point
///
- /// \param Index : index of the point, in range [0, GetNbPoints() - 1]
+ /// \param Index : index of the point, in range [0, GetPointsCount() - 1]
///
/// \return Color of the index-th point
@@ -164,7 +164,7 @@ public :
/// Get the outline color of a point
///
- /// \param index : Index of the point, in range [0, GetNbPoints() - 1]
+ /// \param index : Index of the point, in range [0, GetPointsCount() - 1]
///
/// \return Outline color of the index-th point